@@ -1,6 +1,6 @@
 import pandas as pd
 
-from mofdscribe.datasets.structuredataset import StructureDataset
+from mofdscribe.datasets.structuredataset import StructureDataset, FrameDataset
 
 
 def test_structuredataset(dataset_files, dataset_folder):
@@ -37,3 +37,14 @@ def test_structuredataset(dataset_files, dataset_folder):
     assert len(ds) == 2
     hashes = ds.get_decorated_graph_hashes([0, 1])
     assert len(hashes) == 2
+
+
+def test_framedataset(dataset_files):
+    _, frame = dataset_files
+    frame = pd.read_json(frame[0])
+    ds = FrameDataset(frame,  structure_name_column="info.basename",
+        decorated_graph_hash_column="info.decorated_graph_hash")
+    # only two of them are in the dataframe
+    assert len(ds) == 2
+    hashes = ds.get_decorated_graph_hashes([0, 1])
+    assert len(hashes) == 2
\ No newline at end of file
